# TeamStrange Package

This is a small package for working with time series. The package is mainly build around the existing package pandas, 
however, it focuses on editing specifically time series. The functionalities include import, export, 
changing values in various ways, getting intervals and single data-points, adding, removing, finding and moving 
data-points, and finally, creating peaks in the time series.\
In order to import the TeamStrange Package, just typ "pip install TeamStrange-Martin-Clever" and use "import TimeSeries" 
at the beginning of the code.